import { Plugin } from 'esbuild';

interface ScriptableDeployOptions {
    /**
     * Whether to show detailed logs during deployment
     * Default: false
     */
    verbose?: boolean;
    /**
     * Whether to continue building when deployment fails
     * Default: true
     */
    continueOnError?: boolean;
    /**
     * Custom Scriptable directory path
     * If not specified, will automatically search in iCloud Drive
     */
    scriptableDir?: string;
    /**
     * Source file patterns to match entry points
     * Default: ['**\/*.{ts,tsx,js,jsx}']
     * Examples:
     * -'**\/*.widget.ts'         //only deploy widget files
     * -['**\/*.ts', '!**\/*.test.ts'] //exclude test files
     */
    patterns?: string | string[];
    /**
     * Whether to add Scriptable banner from manifest
     * Default: true
     */
    addBanner?: boolean;
    /**
     * Custom manifest file extensions
     * Default: ['.manifest.json', '.manifest', '.json']
     */
    manifestExtensions?: string[];
}
declare function scriptableDeploy(options?: ScriptableDeployOptions): Plugin;

export { type ScriptableDeployOptions, scriptableDeploy };
